@@ -31,7 +31,7 @@ use DateTime::TimeZone::Local::Unix;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.09991'; # VERSION
+our $VERSION = '0.09992'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -145,11 +145,11 @@ __END__
 =encoding UTF-8
 
 =for :stopwords Jeffrey Ryan Thalhammer BenRifkah Fowler Jakob Voss Karen Etheridge Michael
-G. Bergsten-Buret Schwern Oleg Gashev Steffen Schwigon Tommy Stanton
-Wolfgang Kinkeldei Yanick Boris Champoux brian d foy hesco popl Däppen Cory
-G Watson David Steinbrunner Glenn cpan testmatrix url annocpan anno
-bugtracker rt cpants kwalitee diff irc mailto metadata placeholders
-metacpan
+G. Bergsten-Buret Schwern Nikolay Martynov Oleg Gashev Steffen Schwigon
+Tommy Stanton Wolfgang Boris Kinkeldei Yanick Champoux brian d foy hesco
+popl Däppen Cory G Watson David Steinbrunner Glenn cpan testmatrix url
+annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata
+placeholders metacpan
 
 =head1 NAME
 
@@ -157,7 +157,7 @@ Pinto - Curate a repository of Perl modules
 
 =head1 VERSION
 
-version 0.09991
+version 0.09992
 
 =head1 SYNOPSIS
 
@@ -413,6 +413,10 @@ Michael G. Schwern <schwern@pobox.com>
 
 =item *
 
+Nikolay Martynov <mar.kolya@gmail.com>
+
+=item *
+
 Oleg Gashev <oleg@gashev.net>
 
 =item *
